@@ -12,12 +12,12 @@ from typing import List
 
 from toml import dump as toml_dump
 
-from waterch.tasker import Definition, value
-from waterch.tasker.mixin import ProfileMixin
-from waterch.tasker.storage import DictStorage
+from waterch.tasker.mixin import ProfileMixin, value
+from waterch.tasker.storage import DictStorage, CommonStorageView
 from waterch.tasker.tasks import Task
-from waterch.tasker.typedef import Profile, Return
+from waterch.tasker.typedef import Profile, Return, Definition
 from waterch.tasker.utils import import_reference
+from waterch.tasker._version import version
 
 
 class Launcher(ProfileMixin):
@@ -54,19 +54,31 @@ class Launcher(ProfileMixin):
             prog='waterch-tasker',
             description='A scalable and extendable experiment task scheduler framework'
         )
+        parser.add_argument(
+            '-v', '--version',
+            action='version',
+            version=f'%(prog)s {version}',
+        )
         subcommands = parser.add_subparsers(
             title='command',
-            description='execute this command',
-            dest='command'
+            description='execute a command of waterch-tasker',
+            dest='command',
+            help='choose a command',
+        )
+        launch_parser = subcommands.add_parser(
+            'launch',
+            help='launch tasks by a profile'
         )
-        launch_parser = subcommands.add_parser('launch')
         launch_parser.add_argument(
             '-f', '--file',
             nargs=1,
             required=True,
             help='launch tasks defined by this file'
         )
-        template_parser = subcommands.add_parser('template')
+        template_parser = subcommands.add_parser(
+            'template',
+            help='generate a profile template by a class reference',
+        )
         template_parser.add_argument(
             '-r', '--reference',
             nargs='+',
@@ -191,7 +203,12 @@ class Launcher(ProfileMixin):
             print(f'provide: {" ".join(task.provide())}')
             print(f'{"-" * (slash_number - 1)}>')
             start_time = datetime.now()
-            state = task.invoke(task_profile, shared, task_logger)
+            user_kill = False
+            try:
+                state = task.invoke(task_profile, CommonStorageView(storage=shared, task=task), task_logger)
+            except KeyboardInterrupt:
+                state = Return.WRITE.value
+                user_kill = True
             end_time = datetime.now()
             print(f'<{"-" * (slash_number - 1)}')
             state_label = 'Failed' if state & Return.ERROR.value else 'Successfully finished'
@@ -204,6 +221,9 @@ class Launcher(ProfileMixin):
             if state & Return.EXIT.value:
                 print('Stopped by task.')
                 break
+            if user_kill:
+                print('Stopped by user.')
+                break
             if not (state & Return.RETRY.value):
                 meta_index += 1
 
